<?php

namespace Pinpoint\PaginationCanonicalTags\Helper;

use Magento\Framework\App\RequestInterface;

class Request
{
    /**
     * @var string
     */
    protected const PAGINATION_REQ_PARAM = 'p';

    /**
     * @var array
     */
    protected const ACTIONS_TO_ADD_TAG = ['catalog_category_view'];

    /**
     * @var RequestInterface
     */
    private $request;

    /**
     * @param RequestInterface $request
     */
    public function __construct(
        RequestInterface $request
    ) {
        $this->request = $request;
    }

    /**
     * Returns if we should show a self-referencing canonical tag
     *
     * @return boolean
     */
    public function isToAddCanonicalTag(): bool
    {
        return $this->requestUrlHasPaginationParam() && $this->isPageEligibleForCanonicalTag();
    }

    /**
     * Returns if the request URL contains the pagination query parameter
     *
     * @return bool
     */
    private function requestUrlHasPaginationParam(): bool
    {
        return !empty($this->request->getParam(self::PAGINATION_REQ_PARAM));
    }

    /**
     * Returns if we should be adding the canonical tag to the current page
     *
     * @return bool
     */
    private function isPageEligibleForCanonicalTag(): bool
    {
        return in_array($this->request->getFullActionName(), self::ACTIONS_TO_ADD_TAG);
    }
}
